%% Load and read basal mass flux from input files
        infile1 = 'ts_Ross_WOD_7dot5km_means.nc';                           % unperturbed PISM/PICO simulation of Ross Ice Shelf
        infile2 = 'ts_Ross_WOD_7dot5km_perturbation.nc';                    % perturbed PISM/PICO simulation of Ross Ice Shelf
        infile3 = 'ts_FRIS_WOD_7dot5km_means.nc';                           % unperturbed PISM/PICO simulation of FRIS Ice Shelf
        infile4 = 'ts_FRIS_WOD_7dot5km_perturbation.nc';                    % perturbed PISM/PICO simulation of FRIS Ice Shelf
        load('FGOALS_Temp_C.mat');                                   % CMIP5 GCM model input for ocean potential temperature of Antarctica Ice Shelves
        
        Ross_basal_mass_flux_means = ncread(infile1,'basal_mass_flux_floating');
        Ross_basal_mass_flux_perturbation = ncread(infile2,'basal_mass_flux_floating');
        FRIS_basal_mass_flux_means = ncread(infile3,'basal_mass_flux_floating');
        FRIS_basal_mass_flux_perturbation = ncread(infile4,'basal_mass_flux_floating');
%% Calculate ice flux loss
        % Note that "Positive flux corresponds to ice gain" for PISM
        % simulations
        Ross_basal_ice_loss = (-Ross_basal_mass_flux_perturbation) - (-Ross_basal_mass_flux_means);
        FRIS_basal_ice_loss = (-FRIS_basal_mass_flux_perturbation) - (-FRIS_basal_mass_flux_means);
%% Plot the response for Ross and FRIS ice shelf
        figure(1)
        plot(1:100,Ross_basal_ice_loss,'-o','LineWidth',1.5,...
                    'MarkerSize',7.5,...
                    'MarkerEdgeColor','black',...
                    'MarkerFaceColor','r')
        xlim([0 100])
        ylim([5 40])
        xticks(0:10:100)
        set(gca,'FontSize',12)
%         title('Ross Ice Shelf Basal Melting Reponse','FontSize',12)
        xlabel('Response Year','FontSize',12)
        ylabel('Basal Ice Loss (Gt/yr)','FontSize',12)
        
        figure(2)
        plot(1:100,FRIS_basal_ice_loss,'-o','LineWidth',1.5,...
                    'MarkerSize',7.5,...
                    'MarkerEdgeColor','black',...
                    'MarkerFaceColor','r')
        xlim([0 100])
        ylim([min(FRIS_basal_ice_loss) max(FRIS_basal_ice_loss)])
        xticks(0:10:100)
        set(gca,'FontSize',12)
%         title('Filchner–Ronne Ice Shelf Basal Melting Reponse','FontSize',12)
        xlabel('Response Year','FontSize',12)
        ylabel('Basal Ice Loss (Gt/yr)','FontSize',12)
%% Annual mean of CMIP5 GCM model potential temperature input since 2006
        year = 2006:1:2100;
        for i = 1:length(year)
            Ross_theta(i,1) = mean(Ross(find(Year>=year(i)&Year<=(year(i)+1))));
            FRIS_theta(i,1) = mean(FRIS(find(Year>=year(i)&Year<=(year(i)+1))));
        end
%% Numerical integration to compute melt rate M(t) for both ice shelves
        dt0 = 1;
        M_t_Ross = zeros(length(year),1); % initialize the M(t) time series 
        M_t_FRIS = zeros(length(year),1); % initialize the M(t) time series
        for t = year(2):1:year(end)
            i = find(year==t);
            for t0 = year(1):1:t
                index = find(year==t0);
                T_t0_Ross = Ross_theta(index,1) - (-1.78); % theta above Present-day theta for Ross ice shelf
                T_t0_FRIS = FRIS_theta(index,1) - (-1.54); % theta above Present-day theta for FRIS ice shelf
                if t-t0 > 0
                    temp_Ross = Ross_basal_ice_loss(t-t0) * T_t0_Ross * dt0;
                    temp_FRIS = FRIS_basal_ice_loss(t-t0) * T_t0_FRIS * dt0;
                else
                    temp_Ross = 0;
                    temp_FRIS = 0;
                end
                M_t_Ross(i,1) = M_t_Ross(i,1) + temp_Ross;
                M_t_FRIS(i,1) = M_t_FRIS(i,1) + temp_FRIS;
            end
        end
%% Sea Level Rise Equivalent
        SLR_Ross (1,1) = M_t_Ross(1,1); SLR_FRIS (1,1) = M_t_FRIS(1,1);
        for i = 2:length(year)
            SLR_Ross (i,1) = (M_t_Ross(i) + M_t_Ross(i-1)) / 2;
            SLR_FRIS (i,1) = (M_t_FRIS(i) + M_t_FRIS(i-1)) / 2;
            SLR_Ross (i,2) = sum(SLR_Ross (2:i,1));
            SLR_FRIS (i,2) = sum(SLR_FRIS (2:i,1));
        end
        SLR_Ross(1,2) = SLR_Ross (1,1); SLR_FRIS(1,2) = SLR_FRIS (1,1); 
        SLR_Ross(:,2) = SLR_Ross(:,2) / 361.8; SLR_FRIS(:,2) = SLR_FRIS(:,2) / 361.8;
%% Plot the Ross Ice Shelf melt projection
        load('Ross_Reese.mat')
        load('FRIS_Reese.mat')
        year_Reese = 2015:2100; % time of Reese et al data
      
        figure(3)
        hold on
        
        yyaxis left
        plot(year,M_t_Ross,'-o','LineWidth',1.5,...
                    'MarkerSize',5,...
                    'MarkerEdgeColor','black',...
                    'MarkerFaceColor','b')
        set(gca,'FontSize',12)
        xlim([year(1) year(end)])
        xlabel('Year','FontSize',12)
        ylabel('Basal Ice Loss (Gt/yr)','FontSize',12)
        set(gca,'ycolor',[0.1198, 0.149, 0.5098])
        
        yyaxis right
        plot(year,SLR_Ross(:,2),'-o','LineWidth',1.5,...
            'MarkerSize',5,...
            'MarkerEdgeColor','black',...
            'MarkerFaceColor',[0.851, 0.3255, 0.098])
        ylabel('Global Mean Sea Level Rise (mm)','FontSize',12)
        set(gca,'ycolor','r')
        hold on
        plot(year_Reese,Ross_Reese(5,:)*(10^3),'r','LineWidth',1.5)
        hold on
        curve1 = Ross_Reese(1,:)*(10^3);
        curve2 = Ross_Reese(2,:)*(10^3);
        inBetween1 = [curve1, fliplr(curve2)];
        h1 = fill([year_Reese,fliplr(year_Reese)], inBetween1, 'r','linestyle','none');
        set(h1,'facealpha',.15)
        hold on
        curve3 = Ross_Reese(3,:)*(10^3);
        curve4 = Ross_Reese(4,:)*(10^3);
        inBetween2 = [curve3, fliplr(curve4)];
        h2 = fill([year_Reese,fliplr(year_Reese)], inBetween2, 'r','linestyle','none');
        set(h2,'facealpha',.5)
        legend('Melt Rate (Gt/yr)',...
                'Sea Level Rise Equivalent (mm)',...
                "Reese's Mean (mm)",...
                "Reese's Very Likely Range (mm)",...
                "Reese's Likely Range (mm)",...
                'Location','northwest')
%         title('Ross Ice Shelf Basal Melting Projection','FontSize',12)
        hold off
%% Plot the FRIS Ice Shelf melt projection
        figure(4)
        hold on
        
        yyaxis left
        plot(year,M_t_FRIS,'-o','LineWidth',1.5,...
                    'MarkerSize',5,...
                    'MarkerEdgeColor','black',...
                    'MarkerFaceColor','b')
        set(gca,'FontSize',12)
        xlim([year(1) year(end)])
        xlabel('Year','FontSize',12)
        ylabel('Basal Ice Loss (Gt/yr)','FontSize',12)
        set(gca,'ycolor',[0.1198, 0.149, 0.5098])
        
        yyaxis right
        plot(year,SLR_FRIS(:,2),'-o','LineWidth',1.5,...
            'MarkerSize',5,...
            'MarkerEdgeColor','black',...
            'MarkerFaceColor',[0.851, 0.3255, 0.098])
        ylabel('Global Mean Sea Level Rise (mm)','FontSize',12)
        set(gca,'ycolor','r')
        hold on
        plot(year_Reese,FRIS_Reese(5,:)*(10^3),'r','LineWidth',1.5)
        hold on
        curve1 = FRIS_Reese(1,:)*(10^3);
        curve2 = FRIS_Reese(2,:)*(10^3);
        inBetween1 = [curve1, fliplr(curve2)];
        h1 = fill([year_Reese,fliplr(year_Reese)], inBetween1, 'r','linestyle','none');
        set(h1,'facealpha',.15)
        hold on
        curve3 = FRIS_Reese(3,:)*(10^3);
        curve4 = FRIS_Reese(4,:)*(10^3);
        inBetween2 = [curve3, fliplr(curve4)];
        h2 = fill([year_Reese,fliplr(year_Reese)], inBetween2, 'r','linestyle','none');
        set(h2,'facealpha',.5)
        legend('Melt Rate (Gt/yr)',...
                'Sea Level Rise Equivalent (mm)',...
                "Reese's Mean (mm)",...
                "Reese's Very Likely Range (mm)",...
                "Reese's Likely Range (mm)",...
                'Location','northwest')
%         title('Filchner–Ronne Ice Shelf Basal Melting Projection','FontSize',12)
        hold off