%% load unperturbed, perturbed melt data, potential temperature data
        % and surface runoff data
        load('store.mat')
        load('store_pert.mat')
        load('store_temp.mat')
        load('store_runoff.mat')
        
%% potential temperature time series and plot runoff time series
        year = 2006:1:2100;
        store_temp = Temp_annual;
        
        % plot the potentail temperature time series
        figure(1)
        plot(year,store_temp,'Color','b','LineWidth',1.5)
        xlim([2006 2100])
        ylim([min(store_temp) max(store_temp)])
        set(gca,'FontSize',12)
        xlabel('Year','FontSize',12)
        ylabel('Potential Temperature (Celsius)','FontSize',12)
        
        % plot the potentail temperature time series
        figure(2)
        plot(year,store_runoff,'-o','Color','b','MarkerSize',5,...
                            'MarkerEdgeColor','black',...
                            'MarkerFaceColor','r','LineWidth',1.5)
        xlim([2006 2100])
        ylim([min(store_runoff) max(store_runoff)])
        set(gca,'FontSize',12)
        xlabel('Year','FontSize',12)
        ylabel('Surface Runoff (m^3/s)','FontSize',12)
        
%% response of melt under unit temperature forcing
        response = ave_melt_store_pert - ave_melt_store;
        year_res = 1:10;
        
        % exponential fit for perterbation
        expo = 0.01405*exp(-0.5347*year_res);
        
        % plot the response time series
        figure(3)
        plot(year_res,response(1:10),'r-*','LineWidth',1.35)
        hold on
        plot(year_res,expo,'b-o','LineWidth',1.5)
        xlim([1 10])
        ylim([0 9*10^-3])
        set(gca,'fontsize',12)
        text(year_res(4),expo(3),'R(t) = 0.01405 e^{-0.5347t}','Fontsize',12,'Color', 'b')
        xlabel('Simulation Year','FontSize',12)
        ylabel('Plume Melt Rate (m/day)','FontSize',12)
        legend('Response','Exponential Approx.','Fontsize',12)
        
%% obtain the total melt time series projection
        % first obtain the current melt rate averaged from [0m,-500m]
        melt_now = mean(ave_melt_store);
        
        A = 3*10^(-4);
        h = 500; % grounding line depth
        B = 0.15;
        
        Qsg = store_runoff;
        T = store_temp;
        dt1 = 1;
        % initialize the melt rate vector
        melt = ones(length(year),1) * melt_now;
        for t = 2:length(year)
            for t1 = 1:t
                F = (A*h*(Qsg(t1)^0.39)+B) * T(t1) - (A*h*(Qsg(1)^0.39)+B) * T(1);
                melt_temp = F * 0.01405*exp(-0.5347*(t-t1)) * dt1;
                melt(t) = melt(t) + melt_temp;
            end
        end
        
%% plot the melt rate time series
        figure(4)
        plot(year,melt,'-o','Color','b','MarkerSize',5,...
                            'MarkerEdgeColor','black',...
                            'MarkerFaceColor','r','LineWidth',1.5)
        xlim([2006 2100])
        ylim([min(melt) 4.4])
        set(gca,'FontSize',12)
        xlabel('Simulation Year','FontSize',12)
        ylabel('Plume Melt Rate (m/day)','FontSize',12)