%% ------------------------------------------------------------------------
%     this script is used to find the historical projection of melt water
%  ------------------------------------------------------------------------
        % formulate the response as in Antarctica analyses
        % load and read basal mass flux from input files
        infile1 = 'ts_Ross_WOD_7dot5km_means.nc';                           % unperturbed PISM/PICO simulation of Ross Ice Shelf
        infile2 = 'ts_Ross_WOD_7dot5km_perturbation.nc';                    % perturbed PISM/PICO simulation of Ross Ice Shelf
        infile3 = 'ts_FRIS_WOD_7dot5km_means.nc';                           % unperturbed PISM/PICO simulation of FRIS Ice Shelf
        infile4 = 'ts_FRIS_WOD_7dot5km_perturbation.nc';                    % perturbed PISM/PICO simulation of FRIS Ice Shelf
        
        Ross_basal_mass_flux_means = ncread(infile1,'basal_mass_flux_floating');
        Ross_basal_mass_flux_perturbation = ncread(infile2,'basal_mass_flux_floating');
        FRIS_basal_mass_flux_means = ncread(infile3,'basal_mass_flux_floating');
        FRIS_basal_mass_flux_perturbation = ncread(infile4,'basal_mass_flux_floating');
        
        % Calculate ice flux loss
        % Note that "Positive flux corresponds to ice gain" for PISM
        % simulations
        Ross_basal_ice_loss = (-Ross_basal_mass_flux_perturbation) - (-Ross_basal_mass_flux_means);
        FRIS_basal_ice_loss = (-FRIS_basal_mass_flux_perturbation) - (-FRIS_basal_mass_flux_means);
        
%% Carry out the historical analyses for both ice shelves and plot the results    
        IceShelf = {'Ross';'FRIS'};
        % ice shelf loop computation
        % IS = 1 is Ross ; IS = 2 is FRIS
        for IS = 1:length(IceShelf)
            
            % set the response to coresponding ice shelf
            if IS ==1; basal_ice_loss = Ross_basal_ice_loss; end
            if IS ==2; basal_ice_loss = FRIS_basal_ice_loss; end
            
            % load the file that contain the forcing for the ice shelf
            % retreived from CMIP5 GCMs, each loaded file contain one 
            % structure called "melt_hist" with following 4 fileds :
                % field 1 : GCM names
                % field 2 : historical ocean potential temperature time series
                % field 3 : rcp85 ocean potential temperature time series
                % field 4 : rcp26 ocean potential temperature time series
            file_IceShelf = [IceShelf{IS} '_hist.mat'];
            load(file_IceShelf);
            
            dt0 = 1/12; % the temporal resolution is month
            % GCM loop computation
            for GCM = 1:length(melt_hist)
                
                % first, concatenate the historical with rcp26 / rcp85 files
                % rcp = 1 is rcp2.6 ; rcp = 2 is rcp8.5
                melt_hist(GCM).temp{1} = [melt_hist(GCM).temp_hist;melt_hist(GCM).temp_rcp26];% rcp 2.6
                melt_hist(GCM).temp{2} = [melt_hist(GCM).temp_hist;melt_hist(GCM).temp_rcp85];% rcp 8.5
                
                % rcp loop computation
                for rcp = 1:2
                    
                    % only the HadGEM2-ES starts from 1860 to 2006
                    if string(melt_hist(GCM).GCM) == 'HadGEM2-ES'
                        melt_hist(GCM).year{rcp} = (1860:dt0:1860-dt0+length(melt_hist(GCM).temp{rcp})*dt0)';
                    % the rest models all start from 1850 to 2006
                    else
                        melt_hist(GCM).year{rcp} = (1850+dt0:dt0:1850+length(melt_hist(GCM).temp{rcp})*dt0)';
                    end
                    
                    % variable exchange, use shorter names
                    hist = melt_hist(GCM).temp{rcp}; % use shorter name variable for temperature forcing
                    year = melt_hist(GCM).year{rcp}; % use shorter name variable for year
                    
                    M_t_proj = zeros(length(year),1);% initialize the M(t) time series as zero array
                    
                    % --------convolutional integration -------------------
                    % the first time point will be zero value
                    for t = 2:length(year)
                        for t0 = 1:t
                            % potential temperature difference with beginning year level
                            T_t0 = hist(t0,1) - hist(1);
                            % compute the temperory response value at each time step
                            % if response time is within 100 years, use R(t-t0)
                            if t-t0>0 & t-t0<=100
                                resp = basal_ice_loss(ceil(year(t)-year(t0))) * T_t0 * dt0;
                            else
                                % if response time is larger than 100 years, use R(100)
                                if t-t0>0
                                    resp = basal_ice_loss(end) * T_t0 * dt0;
                                else % if t-t0=0, R(0) = 0
                                    resp = 0;
                                end
                            end
                            M_t_proj(t,1) = M_t_proj(t,1) + resp;
                        end
                    end
                    melt_hist(GCM).proj{rcp} = M_t_proj;
                    % --------convolutional integration end ---------------
                    
                end % end of rcp loop
            end % end of GCM loop
            
            % -------------plot the results -------------------------------
            % plot the ocean temperature time series
            plot_ocean_temp(melt_hist,IS);
            
            % plot the melt rate time series
            plot_melt_rate(melt_hist,IS);
            % -------------plot the results end----------------------------
            
        end % end of ice shelf loop