function plot_melt_rate(melt_hist,IS)
        figure(5)
        if IS == 1
            set(gcf,'Position',[1200 0 900 1100]);
            mytile = tiledlayout(2,1,'TileSpacing','Compact','Padding','Compact');
        end
        
        nexttile(IS)
        
        color = {'m',[0 0.4470 0.7410],'c',[0.4940 0.1840 0.5560],'k',[0.9290 0.6940 0.1250]};
        
        % load the data from Adusumilli et al 2020
        
        % Reference: Adusumilli S, Fricker HA, Medley B, Padman L, 
        % Siegfried MR (2020) Interannual variations in meltwater input 
        % to the Southern Ocean from Antarctic ice shelves. 
        % Nat Geosci 13(9):616620. https://doi.org/10.1038/s41561-020-0616-z
        
        load('ra_all_iceshelf_wb_averages_filter.mat','t','wb_ra_ross','wb_ra_ross_se','wb_ra_fris','wb_ra_fris_se')
        % find time between 1994 and 2018
        time_wb = find(t>=1994);
        % calculate the meltwater flux relative to 1994 level
        if IS ==1;  diff_melt_1994 = wb_ra_ross(time_wb) - wb_ra_ross(time_wb(1)); uncertainty = wb_ra_ross_se; end
        if IS ==2;  diff_melt_1994 = wb_ra_fris(time_wb) - wb_ra_fris(time_wb(1)); uncertainty = wb_ra_fris_se; end
        
        
        % GCM loop to plot the projection between 1994 and 2018
        for GCM = 1:length(melt_hist)
            for rcp = 1:2
                year = melt_hist(GCM).year{rcp};
                M_t_proj = melt_hist(GCM).proj{rcp};
                % the year index is between 1994 and t(end)
                year_ind = find( year>=1994 & year<=t(end) );
                M_t_proj_1994 = M_t_proj(year_ind) - M_t_proj(year_ind(1));
                % dashed lines for RCP 2.6
                if rcp ==1; plot(year(year_ind),M_t_proj_1994,'--','Color',color{GCM},'LineWidth',2.0); end
                % solid lines for RCP 8.5
                if rcp ==2; plot(year(year_ind),M_t_proj_1994,'Color',color{GCM},'LineWidth',2.0); end
                hold on
            end
        end
        % plot Adusumilli et al 2020
        plot(t(time_wb),diff_melt_1994,'r','LineWidth',2.0)
        hold on
        % plot Adusumilli uncertainty
        wb_max = diff_melt_1994 + uncertainty(time_wb);
        wb_min = diff_melt_1994 - uncertainty(time_wb);
        inBetween = [wb_max; flipud(wb_min)];
        fill([t(time_wb);flipud(t(time_wb))], inBetween,'r','linestyle','none','facealpha',.35);
        
        % add grey shade to left historcial
        X = [1994, 1994, 2006, 2006];  
        Y = [-1000, 1000, 1000, -1000];
        fill(X, Y,'k','linestyle','none','facealpha',.15)
        
        if IS==1
            text(0.02,0.95,'a','Units','normalized','FontSize',16,'fontweight', 'bold');
            text(0.1,0.9,'Ross ice shelf','Units','normalized','FontSize',20,'HorizontalAlignment','left');
        else
            text(0.02,0.95,'b','Units','normalized','FontSize',16,'fontweight', 'bold');
            text(0.1,0.9,'FRIS','Units','normalized','FontSize',20,'HorizontalAlignment','left');
        end
        text(0.25,0.1,'Historical','Units','normalized','FontSize',16,'HorizontalAlignment','center');
        text(0.75,0.1,'Projection','Units','normalized','FontSize',16,'HorizontalAlignment','center');
        set(gca,'FontSize',12,'XTick',1994:2:2018,'box','off')
        xlabel('Year')
        ylabel('Basal ice loss (Gt/yr)')
        xlim([1994 2018])
        ylim([-200 300])
        xline(2006,'--','FontSize',14,...
            'LabelHorizontalAlignment','left','LabelOrientation','horizontal','LabelVerticalAlignment','bottom');
        xline(2006,'--','FontSize',14,...
            'LabelHorizontalAlignment','right','LabelOrientation','horizontal','LabelVerticalAlignment','bottom');

        % add legends only after second tile
        if IS ==2
        legends_rcp85 = cellfun(@(c)[c ' RCP8.5'],{melt_hist(1:end).GCM}','uni',false);
        legends_rcp26 = cellfun(@(c)[c ' RCP2.6'],{melt_hist(1:end).GCM}','uni',false);
        legends_rcp = [legends_rcp26,legends_rcp85];
        legends = reshape(legends_rcp',[],1);
        lgd = legend(legends{:},"Adusumilli's mean","Adusumilli's uncertainty",'Box','off','Location','southoutside','FontSize',10);
        lgd.NumColumns = 4;
        end
        
end